from setuptools import setup, find_packages
import os

# Read the README for the long description
with open(os.path.join(os.path.dirname(__file__), 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='ai_agent_system',
    version='1.2.2',
    description='A comprehensive AI agent framework with memory, tool integration, visible reasoning, and enhanced output formatting with colors, animations, and syntax highlighting.',
    long_description=long_description,
    long_description_content_type='text/markdown',
    author='Paul Gedeon',
    packages=find_packages(exclude=['*.chroma_db*', '*.screenshots*', '*.demo_memory*', '*.agent_memory*', '*.examples*']),
    install_requires=[
        'openai>=1.0.0',
        'chromadb>=0.4.0',
        'sentence-transformers>=2.2.0',
        'beautifulsoup4>=4.12.0',
        'requests>=2.31.0',
        'markdown>=3.5.0',
        'pillow>=10.0.0',
        'playwright>=1.40.0',
        'fastapi>=0.104.0',
        'uvicorn>=0.24.0',
        'pydantic>=2.5.0',
        'python-multipart>=0.0.6',
    ],
    entry_points={
        'console_scripts': [
            'ai-agent-system = core.cli:main_cli',
        ],
    },
    python_requires='>=3.8',
    include_package_data=True,
    package_data={},
    url='https://github.com/PaulGG-Code/ai_agent_system_complete',
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
) 